.. _index:

=============
Tryton Server
=============

First steps
===========

    * **Installation:**
      :ref:`Installation <topics-install>` |
      :ref:`Configuration <topics-configuration>` |
      :ref:`Setup a database <topics-setup-database>` |
      :ref:`Start the server <topics-start-server>`

The model layer
===============

    * **Models:**
      :ref:`Model syntax <topics-models>` |
      :ref:`Field types <ref-models-fields>` |
      :ref:`Domain syntax <topics-domain>` |
      :ref:`Access rights <topics-access_rights>` |
      :ref:`Triggers <topics-triggers>`

The view layer
==============

    * **Views:**
      :ref:`View types <topics-views>` |
      :ref:`Extension <topics-extension>`

    * **Reports:**
      :ref:`Report definition <topics-reports>`

The development process
=======================

    * **Modules**
      :ref:`Module definition <topics-modules>`

Contents
========

.. toctree::
    :maxdepth: 2

    topics/index
    ref/index

Indices, glossary and tables
============================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
